@@ -25,7 +25,7 @@ byComplexity <- function(x, model)
            },
            rf =, rfNWS =, rfLSF =, parRF =, gpls =, pcr =, pls =, PLS =, pam =, cforest =,
            nb =, rpart =, ctree2 =, logitBoost=, J48 =, LMT =, ppr =, mda =, pda =, pda2 =,
-           lars =, lars2 =, Linda =, QdaCov = 
+           lars =, lars2 =, Linda =, QdaCov =, icr =  
            {
              x[order(x[,1]),]
            },
